Models and Managers
*******************

.. automodule:: media_tree.models
   :members:
   :inherited-members:
   :exclude-members: clean, clean_fields, full_clean, save_base, 
      serializable_value, validate_unique
